speclite package
================

.. image:: http://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: http://www.astropy.org
    :alt: Powered by Astropy Badge

This package provides a set of lightweight utilities for working with spectroscopic data in astronomy.

* Free software: 3-clause BSD style license.
* Documentation: `latest <http://speclite.readthedocs.org/en/latest/>`_ | `stable <http://speclite.readthedocs.org/en/stable/>`_
* Based on the Astropy affiliated package template.

Speclite has the following package requirements:

* `numpy <http://www.numpy.org/>`__
* `scipy <http://www.scipy.org/>`__
* `astropy <http://www.astropy.org/>`__
* `pyyaml <http://pyyaml.org>`__

Status reports for developers
-----------------------------

.. image:: https://travis-ci.org/dkirkby/speclite.png?branch=master
    :target: https://travis-ci.org/dkirkby/speclite
    :alt: Test Status

.. image:: https://readthedocs.org/projects/speclite/badge/?version=latest
    :target: https://readthedocs.org/projects/speclite/?badge=latest
    :alt: Documentation Status

.. image:: https://coveralls.io/repos/dkirkby/speclite/badge.svg?branch=master&service=github
    :target: https://coveralls.io/github/dkirkby/speclite?branch=master
    :alt: Coverage Status

.. image:: https://img.shields.io/pypi/v/speclite.svg
    :target: https://pypi.python.org/pypi/speclite
    :alt: Distribution Status
